@@ -350,7 +350,7 @@ int GWEN_SyncIo_Tls_Prepare(GWEN_SYNCIO *sio) {
   }
 
   /* set default priority */
-#if 0 /* old code */
+#if 1 /* old code */
   GWEN_Gui_ProgressLog(0, GWEN_LoggerLevel_Error, I18N("Using old SSL preparation code."));
   rv=gnutls_set_default_priority(xio->session);
   if (rv) {
@@ -361,12 +361,12 @@ int GWEN_SyncIo_Tls_Prepare(GWEN_SYNCIO *sio) {
 
   /* possibly force protocol priority */
   if (lflags & GWEN_SYNCIO_TLS_FLAGS_FORCE_SSL_V3) {
-    const int proto_prio[2] = { GNUTLS_SSL3, 0 };
+    char *force_sslv3_str = "NORMAL:-VERS-TLS-ALL:+VERS-SSL3.0";
 
     DBG_INFO(GWEN_LOGDOMAIN, "Forcing SSL v3");
-    rv=gnutls_protocol_set_priority(xio->session, proto_prio);
+    rv=gnutls_priority_set_direct(xio->session, force_sslv3_str, NULL);
     if (rv) {
-      DBG_ERROR(GWEN_LOGDOMAIN, "gnutls_protocol_set_priority: %d (%s)", rv, gnutls_strerror(rv));
+      DBG_ERROR(GWEN_LOGDOMAIN, "gnutls_priority_set_direct: %d (%s)", rv, gnutls_strerror(rv));
       gnutls_deinit(xio->session);
       return GWEN_ERROR_GENERIC;
     }
@@ -490,6 +490,7 @@ int GWEN_SyncIo_Tls_Prepare(GWEN_SYNCIO *sio) {
   /* find default trust file if none is selected */
   if (lflags & GWEN_SYNCIO_TLS_FLAGS_ADD_TRUSTED_CAS) {
     int trustFileSet=0;
+#if 0
 # ifndef OS_WIN32
     /* try to find OpenSSL certificates */
     if (trustFileSet==0) {
@@ -501,7 +502,7 @@ int GWEN_SyncIo_Tls_Prepare(GWEN_SYNCIO *sio) {
 
       nbuf=GWEN_Buffer_new(0, 256, 0, 1);
       rv=GWEN_Directory_FindFileInPaths(paths,
-                                        "ca-bundle.crt",
+                                        "ca-certificates.crt",
                                         nbuf);
       GWEN_StringList_free(paths);
       if (rv==0) {
@@ -528,7 +529,6 @@ int GWEN_SyncIo_Tls_Prepare(GWEN_SYNCIO *sio) {
 # endif
 
 
-#if 0
 # ifndef OS_WIN32
     /* try to find ca-certificates (at least available on Debian systems) */
     if (trustFileSet==0) {
